<?php
/**
 * @file
 * Contains \Drupal\engagebay\Form\EngageBayConfigurationForm.
 */

namespace Drupal\engagebay\Form;

use Drupal;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\engagebay\Service\EngageBayAPI;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

class EngageBayConfigurationForm extends FormBase
{
  const ENGAGEBAY_VARS = 'engagebay_vars';

  public function getFormId(): string
  {
    return 'engagebay_configuration_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state)
  {
    $engagebay_domain = $this->configFactory()->getEditable('engagebay.settings')->get('domain');

    if (array_key_exists('HTTP_REFERER', $_SERVER)) {
      if (!str_contains($_SERVER['HTTP_REFERER'], 'engagebay/home') && $engagebay_domain) {
        return $this->redirect('engagebay.home');
      }
    } else if ($engagebay_domain) {
      return $this->redirect('engagebay.home');
    }

    $this->configFactory()->getEditable('engagebay.settings')->delete();

    $form['username'] = [
      '#type' => 'email',
      '#title' => t('Username: '),
      '#required' => TRUE
    ];

    $form['password'] = [
      '#type' => 'password',
      '#title' => t('Password: '),
      '#required' => TRUE
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Connect'),
      '#button_type' => 'primary'
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    if ($form_state->isValidationComplete() && array_key_exists(self::ENGAGEBAY_VARS, $form)) {
      $this->configFactory()
        ->getEditable('engagebay.settings')
        ->set('domain', $form[self::ENGAGEBAY_VARS]['domain_name'])
        ->set('email', $form[self::ENGAGEBAY_VARS]['email'])
        ->set('rest_api_key', $form[self::ENGAGEBAY_VARS]['api_key']['rest_API_Key'])
        ->set('js_api_key', $form[self::ENGAGEBAY_VARS]['api_key']['js_API_Key'])
        ->save();

      $form_state->setRedirectUrl(Drupal\Core\Url::fromRoute('engagebay.home'));
    }
  }

  public function validateForm(array &$form, FormStateInterface $form_state)
  {
    parent::validateForm($form, $form_state);

    $engageBay = new EngageBayAPI();
    $login_response = $engageBay->login($form_state->getValue('username'), $form_state->getValue('password'));

    if ($login_response) {
      $form[self::ENGAGEBAY_VARS] = $login_response;
    } else {
      $form_state->setErrorByName('Login', 'Invalid Credentials or Too many login attempts');
      $this->configFactory()
        ->getEditable('engagebay.settings')
        ->delete();
    }
  }

  public function onInputChange(array &$form, FormStateInterface $form_state, Request $request)
  {
    $response = new Drupal\Core\Ajax\AjaxResponse();

    $response->addCommand(new Drupal\Core\Ajax\InvokeCommand('submit-config', 'onInputChange', ['Connect']));

    return $response;
  }
}
